#pragma once

#include "emc/nml_intf/emctool.h"

namespace standalone {

void reset_tool_adapter();
void set_tool_entry(int index, const CANON_TOOL_TABLE &tool);
CANON_TOOL_TABLE tool_entry_init();
int find_tool_index_for_tool(int toolno);
int get_tool_entry(CANON_TOOL_TABLE *tool, int index);
int current_tool_index();
int selected_tool_index();
void select_tool(int toolno);
void change_selected_tool();
void change_tool_number(int index);

}  // namespace standalone
